// Smart Litter Box Sensor - Sample code
//
// Developed (compiled) by Will Crum @ SVA's Products of Design,
// with immense help from the example-code writers at Arduino and Adafruit.
// Thank you all!
//
// Thank you, Todd Treece @ Adafruit Industries, for providing the foundation for this code.
// Copyright (c) 2016 Adafruit Industries
// Licensed under the MIT license.


/************************** Network Configuration ***********************************/

// edit the config.h tab and enter your Adafruit IO credentials
// and any additional configuration needed for WiFi, cellular,
// or ethernet clients.
#include "config.h"

/************************ Example Starts Here *******************************/

// set up the 'gasSensor' feed
AdafruitIO_Feed *gasSensor = io.feed("litterbox-monitor-serial");

#define LED 13

const int analogPin = A0;    // pin that the sensor is attached to
const int ledPin = 13;       // pin that the LED is attached to
const int threshold = 150;   // an arbitrary threshold level that's in the range of the analog input. 

// Once you've installed your sensor in its final environment, you'll want to change
// the 'threshold' number above based on what the serial monitor is reading when you think it's
// problematically stinky. After all, odor is subjective! (And this sensor is variable)

//this code uses a boolean true/false command, which enables the Feather
//to test for two different scenarios (is the serial reading is above/below 150?),
//and then run different commands based on this determination

bool stinky = false;

void setup() {

  // start the serial connection
  Serial.begin(115200);

  // wait for serial monitor to open
  while (! Serial);

  Serial.print("Connecting to Adafruit IO");

  // connect to io.adafruit.com
  io.connect();

  // wait for a connection
  while (io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

  //activating gas sensor read
  //defining LED pins for digital output
  Serial.println("MiCS-5524 demo!");
  pinMode(ledPin, OUTPUT);

}

void loop() {

  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. it keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();

  //reading sensor value
  int analogValue = analogRead(analogPin);

  if (!stinky) {
    //monitoring sensor reading
    int reading = analogRead(A0);

    // save value to the 'gasSensor' feed on Adafruit IO
    Serial.print("sending -> ");
    Serial.println(reading);
    gasSensor->save(reading);
    digitalWrite(ledPin, LOW);
    // wait one second (1000 milliseconds == 1 second)
    delay(1000);
  }

  if (stinky) {
    //sending a false negative to IFTTT (so it doesn't send you 60 messages in a minute!)
    gasSensor->save(0);
    Serial.print("sending -> 0");
    digitalWrite(ledPin, HIGH);
    //ensuring sensor is read every 1000 milliseconds
    delay(1000);

  }

  // if the analog value is high enough, turn on the LED:
  if (analogValue > threshold) {
    stinky = true;
  } else {
    stinky = false;
  }

}
